convert to sicd utility (sarpy.utils.convert_to_sicd)
=====================================================

.. automodule:: sarpy.utils.convert_to_sicd
    :members:
    :show-inheritance:
    :inherited-members:
